@@ -1,7 +1,6 @@
 package tempfile
 
 import (
-	"context"
 	"fmt"
 	"os"
 	"path/filepath"
@@ -9,12 +8,13 @@ import (
 	"strings"
 	"testing"
 
+	"github.com/gopasspw/gopass/internal/config"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
 func Example() {
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	tempfile, err := New(ctx, "gopass-secure-")
 	if err != nil {
@@ -68,7 +68,7 @@ func TestTempdirBaseEmpty(t *testing.T) {
 func TestTempFiler(t *testing.T) {
 	t.Parallel()
 
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	// regular tempfile
 	tf, err := New(ctx, "gp-test-")
@@ -103,7 +103,7 @@ func TestGlobalPrefix(t *testing.T) {
 
 		assert.True(t, strings.HasPrefix(fileOrDirName, requirePrefix))
 	}
-	ctx := context.Background()
+	ctx := config.NewContextInMemory()
 
 	assert.Equal(t, "", globalPrefix)
 
